==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/PopupType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PopupType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PopupType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="rectangle" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="isOpen" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PopupType", propOrder = {
    "rectangle"
})
public class PopupType {

    @XmlElement(required = true)
    protected RectangleType rectangle;
    @XmlAttribute(name = "isOpen")
    protected Boolean isOpen;

    /**
     * Gets the value of the rectangle property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getRectangle() {
        return rectangle;
    }

    /**
     * Sets the value of the rectangle property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setRectangle(RectangleType value) {
        this.rectangle = value;
    }

    public boolean isSetRectangle() {
        return (this.rectangle!= null);
    }

    /**
     * Gets the value of the isOpen property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsOpen() {
        if (isOpen == null) {
            return false;
        } else {
            return isOpen;
        }
    }

    /**
     * Sets the value of the isOpen property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsOpen(boolean value) {
        this.isOpen = value;
    }

    public boolean isSetIsOpen() {
        return (this.isOpen!= null);
    }

    public void unsetIsOpen() {
        this.isOpen = null;
    }

}

==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/info/PopupType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;


/**
 * <p>Java class for PopupType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PopupType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="rectangle" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="isOpen" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PopupType", propOrder = {
    "rectangle"
})
@JsonIgnoreProperties(ignoreUnknown = true)
public class PopupType {

    @XmlElement(required = true)
    protected RectangleType rectangle;
    @XmlAttribute(name = "isOpen")
    protected Boolean isOpen;

    /**
     * Gets the value of the rectangle property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getRectangle() {
        return rectangle;
    }

    /**
     * Sets the value of the rectangle property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setRectangle(RectangleType value) {
        this.rectangle = value;
    }

    public boolean isSetRectangle() {
        return (this.rectangle!= null);
    }

    /**
     * Gets the value of the isOpen property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsOpen() {
        if (isOpen == null) {
            return false;
        } else {
            return isOpen;
        }
    }

    /**
     * Sets the value of the isOpen property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsOpen(boolean value) {
        this.isOpen = value;
    }

    public boolean isSetIsOpen() {
        return (this.isOpen!= null);
    }

    public void unsetIsOpen() {
        this.isOpen = null;
    }

}
